@@ -25,13 +25,27 @@ FunctionParameterTypeFactory <- function() {
 
   isPureReal <- function(o_1_) is.double(o_1_) && !is.na(o_1_)
 
+  isUnsignedReal <- function(o_1_) isPureReal(o_1_) && o_1_ >= 0.0
+
+  isUnsignedInteger <- function(o_1_) isPureMathInteger(o_1_) && o_1_ >= 0L
+
+  isString <- function(o_1_) is.character(o_1_) && !is.na(o_1_)
+
   allowedSuffixes <- list(
     list('a'   , 'array'        , list(is.array)                   , type_classes$data_structure),
     list('b'   , 'boolean'      , list(isPureBoolean)              , type_classes$math),
+
     list('c'   , 'complex'      , list(is.complex)                 , type_classes$numeric),
     list('cm'  , 'complex-math' , list(isPureComplex)              , type_classes$math),
-    list('ca'  , 'call'         , list(is.call)                    , type_classes$language),
+
     list('d'   , 'double'       , list(is.double)                  , type_classes$numeric),
+    list('r'   , 'real-math'    , list(isPureReal)                 , type_classes$math),
+
+    list('ch'  , 'character'    , list(is.character)               , type_classes$basic),
+    list('s'   , 'string'       , list(isString)                   , type_classes$basic),
+
+    list('ca'  , 'call'         , list(is.call)                    , type_classes$language),
+
     list('da'  , 'date'         , list(lubridate::is.Date)         , type_classes$date),
     list('dc'  , 'POSIXct'      , list(lubridate::is.POSIXct)      , type_classes$date),
     list('df'  , 'data.frame'   , list(is.data.frame)              , type_classes$data_structure),
@@ -52,11 +66,13 @@ FunctionParameterTypeFactory <- function() {
     list('na'  , 'na'           , list(is.na)                      , type_classes$basic),
     list('nm'  , 'name'         , list(is.name)                    , type_classes$language),
     list('o'   , 'object'       , list(is.object)                  , type_classes$basic),
-    list('r'   , 'real-math'    , list(isPureReal)                 , type_classes$math),
-    list('ra'  , 'raw'          , list(is.raw)                     , type_classes$basic),
-    list('s'   , 'string'       , list(is.character)               , type_classes$basic),
-    list('t'   , 'table'        , list(is.table)                   , type_classes$data_structure),
-    list('w'   , 'warning'      , list(isWarning)                  , type_classes$error)
+
+    list('ra'  , 'raw'             , list(is.raw)                  , type_classes$basic),
+
+    list('ui'  , 'unsigned integer', list(isUnsignedInteger)      , type_classes$math),
+    list('ur'  , 'unsigned real'   , list(isUnsignedReal)         , type_classes$math),
+    list('t'  , 'table'            , list(is.table)                 , type_classes$data_structure),
+    list('w'   , 'warning'         , list(isWarning)               , type_classes$error)
   )
 
   suffix <- NULL # data.table NSE issue with Rcmd check
@@ -90,7 +106,7 @@ FunctionParameterTypeFactory <- function() {
 
   getVerificationFunction <- function(value_s_1) {
     rn <- getRowNumber(value_s_1[1])
-    if (is.na(rn)) return(paste('No suffix or type matches', strBracket(value_s_1[1])))
+    if (is.na(rn)) return(paste('No verification function', strBracket(value_s_1[1])))
     dt[rn]$verify_function[[1]]
   }
 
